cap log close
log using andescr4, replace
clear
set mem 256m
use cito4work

// some interactions for regressions
foreach y in 2002 2003 {
	g treatp`y' = (jaar==`y')*treatp
	g eligp`y' = (jaar==`y')*eligp
	g treatc`y' = (jaar==`y')*treatc
	g eligc`y' = (jaar==`y')*eligc
}

g double classid = 10000*schoolnr + jaar

tab denom, g(Ddenom)
tab schoolgr, g(Dsgr)
tab stedhd, g(Dsted)

g byte all=1

// generate higher order terms
g sharep2 = sharep^2
g sharep3 = sharep^3
g sharec2 = sharec^2
g sharec3 = sharec^3

// nr of test takers
bys schoolnr jaar : g n = _N

// define control vars
unab xvars : girl Ddenom* Dsted* leeft vrouw total98 total99 n

// Table 3
foreach v of var taal reken info sharep sharec Dsg* Dst* Dd* {
	di as text abbrev("`v'",15) _col(16) " " _c
	foreach grp of var all p5 p10 c5 c10 {
		qui sum `v' if `grp'==1 & jaar==2002, mean
		di as res %9.3f r(mean) _c
	}
	di
}


// Table 4 A. All Schools
qui foreach out in taal reken info {
  noi di as text "`out'"  _col(8) _c
  xi: ivreg `out' (treatp treatc = eligp eligc) `xvars' i.jaar*sharep i.jaar*sharec if jaar>=2002, cluster(classid)
  noi di as res %7.3f _b[treatp] %7.3f _se[treatp] %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp treatc = eligp eligc) `xvars' i.jaar*sharep i.jaar*sharep2 i.jaar*sharec i.jaar*sharec2 if jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp treatc = eligp eligc) `xvars' i.jaar*sharep i.jaar*sharep2 i.jaar*sharep3 i.jaar*sharec i.jaar*sharec2 i.jaar*sharec3 if jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] %7.3f _b[treatc] %7.3f _se[treatc]
}


// Table 4 B. DS10 - correct (the table in the paper mistakely uses pre intervention years)
// note: no interactions between shares and year dummies
qui foreach out in taal reken info {
  noi di as text "`out'"  _col(10) _c
  // DS estimates
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep if p10==1 & jaar>=2002, cluster(classid) 
  noi di as res %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec if c10==1 & jaar>=2002, cluster(classid) 
  noi di %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep sharep2 if p10==1 & jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec sharec2 if c10==1 & jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep sharep2 sharep3 if p10==1 & jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec sharec2 sharec3 if c10==1 & jaar>=2002, cluster(classid)
  noi di %7.3f _b[treatc] %7.3f _se[treatc]
}

/* Table 4 B. DS10 - like in paper
qui foreach out in taal reken info {
  noi di as text "`out'"  _col(10) _c
  // DS estimates
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep if p10==1 & (jaar>=2002 | jaar<=2000), cluster(classid) 
  noi di as res %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec if c10==1 & (jaar>=2002 | jaar<=2000), cluster(classid) 
  noi di %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep sharep2 if p10==1 & (jaar>=2002 | jaar<=2000), cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec sharec2 if c10==1 & (jaar>=2002 | jaar<=2000), cluster(classid)
  noi di %7.3f _b[treatc] %7.3f _se[treatc] _c
  xi: ivreg `out' (treatp = eligp) `xvars' i.jaar sharep sharep2 sharep3 if p10==1 & (jaar>=2002 | jaar<=2000), cluster(classid)
  noi di %7.3f _b[treatp] %7.3f _se[treatp] _c
  xi: ivreg `out' (treatc = eligc) `xvars' i.jaar sharec sharec2 sharec3 if c10==1 & (jaar>=2002 | jaar<=2000), cluster(classid)
  noi di %7.3f _b[treatc] %7.3f _se[treatc]
}
*/

// Tables 5 & 6
foreach tr in p c {
 di as text "treatment = `tr'"
 foreach out in taal reken info {
  foreach p in 5 10 {
	di as text "`out', ds=" %2.0f `p' _col(15) _c
	preserve
	qui keep if `tr'`p'==1 & (jaar>=2002 | jaar<=2000)
	// separate for 2002 & 2003
	qui xi: ivreg `out' (treat`tr'2*=elig`tr'2*) i.j i.schoolnr, cluster(classid) robust
	di as res %9.3f _b[treat`tr'2002] %9.3f _se[treat`tr'2002] _c
	di %9.3f _b[treat`tr'2003] %9.3f _se[treat`tr'2003] _c
	qui test treat`tr'2002=treat`tr'2003
	local F = r(F)
	local p = r(p)
	// pooled estimate	
	qui xi: ivreg `out' (treat`tr'=elig`tr') i.j i.schoolnr ,  cluster(classid) robust
	di %9.3f _b[treat`tr'] %9.3f _se[treat`tr'] _c
	// print test
	di %9.3f `F' %9.3f `p'

	restore
  } 
 }
}


// Table A1 & A2
foreach tr in p c {
 di as text "treatment = `tr'"
 foreach out in taal reken info {
  qui foreach p in 5 10 {
	di as text "`out', ds=" %2.0f `p' _col(15) _c
	preserve
	// fake cut-off at 0.5
	keep if inrange(share`tr', 0.5 - `p'/100, 0.5 + `p'/100) & (jaar>=2002 | jaar<=2000)
	replace treat`tr' = share`tr' > 0.5 & jaar>2001   // treatment at fake cut-off
	replace treat`tr'2002 = (jaar==2002)*treat`tr'
	replace treat`tr'2003 = (jaar==2003)*treat`tr'
	// separate for 2002 & 2003
	xi: reg `out' treat`tr'2* i.j i.schoolnr, cluster(classid) robust
	noi di as res %9.3f _b[treat`tr'2002] %9.3f _se[treat`tr'2002] _c
	noi di %9.3f _b[treat`tr'2003] %9.3f _se[treat`tr'2003] _c
	test treat`tr'2002=treat`tr'2003
	local F = r(F)
	local p = r(p)
	// pooled estimate	
	xi: reg `out' treat`tr' i.j i.schoolnr, cluster(classid) robust
	noi di %9.3f _b[treat`tr'] %9.3f _se[treat`tr'] _c
	// print test
	noi di %9.3f `F' %9.3f `p'

	restore
  } 
 }
}


// Table A3
qui foreach p in 5 10 {
	noi di as text "ds=" %2.0f `p'
	preserve
	keep if c`p'==1 & (jaar>=2002 | jaar<=2000)
	qui foreach out in taal reken info {
		noi di as text "`out'" _col(10) _c
		// pooled estimate girls	
		xi: reg `out' treatc i.j i.schoolnr if girl==1,  cluster(classid) robust
		noi di as res %9.3f _b[treatc] %9.3f _se[treatc] _c
		// pooled estimate boys	
		xi: reg `out' treatc i.j i.schoolnr if girl==0,  cluster(classid) robust
		noi di %9.3f _b[treatc] %9.3f _se[treatc]
	}
	restore
}



cap log close
